/*
 * SimpleImageObserver.java
 * Part of the B'am library - a collection of general-purpose utility classes.
 * 
 * Copyright (C)2006 Stephen Battey
 * Contact: resource@lucidviews.net
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

package net.lucidviews.util.image;

import java.awt.image.ImageObserver;
import java.awt.Image;


/**
 * A simple image observer.
 * <br />
 * This <code>ImageObserver</code> takes no action when the
 * <code>imageUpdate</code> method is called, but responds with the value
 * <code>true</code> (keep loading image data) until the image has completely
 * loaded.
 * <br />
 * <br />
 * @see java.awt.image.ImageObserver
 * @see java.awt.Image
 * @author Stephen Battey
 * @version $Revision: 1.3 $
 * @since 1.0
 */
public class SimpleImageObserver extends BaseImageObserver
{

	/*
	 * Exported constants
	 */

	/** A convenient reference to an instance of this observer. */
	public static final SimpleImageObserver INSTANCE = new SimpleImageObserver();


	/*
	 * Implementation of the ImageObserver interface
	 */

	public boolean observedImageUpdate( Image img, int infoflags, int x, int y, int width, int height )
	{
		/* check if the binary data, width and height have loaded */
		boolean pixelsLoaded = (infoflags & ImageObserver.ALLBITS) == ImageObserver.ALLBITS;
		boolean widthLoaded = (infoflags & ImageObserver.WIDTH) == ImageObserver.WIDTH;
		boolean heightLoaded = (infoflags & ImageObserver.HEIGHT) == ImageObserver.HEIGHT;
		boolean propertiesLoaded = (infoflags & ImageObserver.PROPERTIES) == ImageObserver.PROPERTIES;

		/* return true if not all the data has loaded */
		return (!(pixelsLoaded && widthLoaded && heightLoaded && propertiesLoaded));
	}

}


/*
 * Change History
 *
 * $Log: SimpleImageObserver.java,v $
 * Revision 1.3  2006/09/06 20:52:02  Steve
 * Added legal disclaimer.
 *
 * Revision 1.2  2006/09/02 16:40:28  Steve
 * Modified to use the BaseImageObserver base class.
 *
 * Revision 1.1  2006/04/13 14:24:24  Steve
 * Initial revision.
 *
 */
